package com.koossery.alfresco.web.bean.content;

import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;
import javax.transaction.UserTransaction;

import net.sf.jasperreports.engine.JREmptyDataSource;
import net.sf.jasperreports.engine.JasperExportManager;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;

import org.alfresco.model.ContentModel;
import org.alfresco.service.ServiceRegistry;
import org.alfresco.service.cmr.dictionary.DictionaryService;
import org.alfresco.service.cmr.model.FileInfo;
import org.alfresco.service.cmr.repository.AssociationRef;
import org.alfresco.service.cmr.repository.ContentReader;
import org.alfresco.service.cmr.repository.ContentService;
import org.alfresco.service.cmr.repository.ContentWriter;
import org.alfresco.service.cmr.repository.NodeRef;
import org.alfresco.service.namespace.QName;
import org.alfresco.service.namespace.RegexQNamePattern;
import org.alfresco.service.transaction.TransactionService;
import org.alfresco.web.app.AlfrescoNavigationHandler;
import org.alfresco.web.app.Application;
import org.alfresco.web.app.servlet.DownloadContentServlet;
import org.alfresco.web.bean.FileUploadBean;
import org.alfresco.web.bean.dialog.BaseDialogBean;
import org.alfresco.web.bean.repository.Repository;
import org.alfresco.web.ui.common.Utils;
import org.alfresco.web.ui.common.component.UIActionLink;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.core.io.ClassPathResource;

import com.koossery.alfresco.customcontent.model.ProductModel;
import com.koossery.alfresco.customcontent.util.CustomContentUtils;
import com.koossery.alfresco.web.data.ProductData;


/**
 * Create New Product Dialog
 * 
 * @author Landry KOUAM
 *
 */
public class SaveProductDialog extends BaseDialogBean{

	private static final long serialVersionUID = 1L;


	private static Log logger = LogFactory.getLog(SaveProductDialog.class);
	

	/* -------------- Alfresco services ------------------ */
	private ContentService contentService;
	private ServiceRegistry serviceRegistry;

	/* -------------- Data ------------------ */
	private ProductData productData;
	
	private String productRef;

	/* --------------- Outcomes and Actions groups --------------- */
	
	/* --------------- Update Flag --------------- */
	private boolean update = false;

	/* --------------- JASPER REPORT FILE AND RESSOURCES  --------------- */ 
	private ClassPathResource JASPER_REPORT_CONTEXT_PATH=new ClassPathResource("/jasperreport/Product.jasper");
	private ClassPathResource JASPER_REPORT_KOOSSERY_LOGO_PATH=new ClassPathResource("/images/logo/logo_koossery.jpg");
	
	/* --------------- Report bytes  --------------- */
	private byte[] reportBytes;

	/* --------------- Report Parameters  --------------- */
	private  final String PRODUCT_REPORT_DESCRIPTION = "PRODUCT_REPORT_DESCRIPTION";
	private  final String PRODUCT_REPORT_IMAGE = "PRODUCT_REPORT_IMAGE";
	private  final String PRODUCT_REPORT_KOOSSERY_LOGO = "PRODUCT_REPORT_KOOSSERY_LOGO";
	private  final String PRODUCT_REPORT_NAME = "PRODUCT_REPORT_NAME";
	private  final String PRODUCT_REPORT_PRIZE = "PRODUCT_REPORT_PRIZE";
	private  final String PRODUCT_REPORT_REFERENCE = "PRODUCT_REPORT_REFERENCE";
	private  final String PRODUCT_REPORT_STOCK = "PRODUCT_REPORT_STOCK";


	
	@Override
	public void init(Map<String, String> parameters) {

		if(this.update == false){
			productData = new ProductData();	
			this.productRef = "prod-"+System.currentTimeMillis();
		}	
		
		super.init(parameters);
				
	}

	@Override
	protected String finishImpl(FacesContext arg0, String arg1)
			throws Exception {
		
		// In case of creation
		if(this.update == false){
			generateFromPOJO();
			saveReport(this.reportBytes);
			
		}else{
			generateFromPOJO();
			saveUpdateReport(this.reportBytes);
		}

		return AlfrescoNavigationHandler.CLOSE_DIALOG_OUTCOME;
	}

	/**
	 * Set flag for creation
	 */
	public void setupFlagCreate(ActionEvent event){
		this.update = false;
	}
	
	/**
	 * Public helper to setup action page with equipment data
	 * 
	 * @param event
	 */
	public void setupContentAction(ActionEvent event){
	      UIActionLink link = (UIActionLink)event.getComponent();
	      Map<String, String> params = link.getParameterMap();
	      String name = params.get("id");
	      setupContentAction(name, false);

	}

	public void setupContentAction(String name, boolean invalidate)
	{		
		// Set update flag
		this.update = true;

		try {
			// Retrieve product data

			NodeRef nodeRef = new NodeRef(Repository.getStoreRef(), name);			
			
			if(getNodeService().exists(nodeRef)){
				
				this.productData = new ProductData();
				this.productData.setNodeRef(nodeRef);
				
				this.productData.setName((String)getNodeService().getProperty(nodeRef, ProductModel.PROP_NAME));
				this.productData.setDescription((String)getNodeService().getProperty(nodeRef, ProductModel.PROP_DESCRIPTION));
				this.productData.setRef((String)getNodeService().getProperty(nodeRef, ProductModel.PROP_REF));
				this.productRef = (String)getNodeService().getProperty(nodeRef, ProductModel.PROP_REF);
				this.productData.setPrize((Float)getNodeService().getProperty(nodeRef, ProductModel.PROP_PRIZE));
				this.productData.setStock((Integer)getNodeService().getProperty(nodeRef, ProductModel.PROP_STOCK));				

				List<AssociationRef> assocRefs = getNodeService().getTargetAssocs(nodeRef, RegexQNamePattern.MATCH_ALL);
				DictionaryService dd = Repository.getServiceRegistry(
			              FacesContext.getCurrentInstance()).getDictionaryService();

				if(assocRefs != null){						
					for (AssociationRef associationRef : assocRefs) {
						// Retrieve Photos
						if(dd.isSubClass(getNodeService().getType(associationRef.getTargetRef()), ProductModel.TYPE_IMAGE)){								
							retrievePhoto(associationRef);
						}		
					}
				}	

			}
			
		}catch (Throwable e) {
			logger.error(e.getMessage());
		}

	}

		/*
		 * Retrieve a photo
		 */ 
		private void retrievePhoto(AssociationRef associationRef){
			FacesContext fc = FacesContext.getCurrentInstance();
			
			try {
				NodeRef photoNodeRef = null;
				photoNodeRef = associationRef.getTargetRef();
				
				// Get properties
				productData.setPhotoLegend((String)getNodeService().getProperty(photoNodeRef, ProductModel.PROP_PICTURELEGEND));
				productData.setPhotoFileName("");
				productData.setPhotoNodeRef(photoNodeRef);

				// get a reader for the content and get the file
				ContentReader reader = getContentService().getReader(photoNodeRef, ContentModel.PROP_CONTENT);
				if(reader!=null && reader.exists()){
					productData.setPhotoInputStream(reader.getContentInputStream());
				}								
				
			} catch (Throwable e) {
				Utils.addErrorMessage(Application.getMessage(fc, MSG_RETRIEVEPHOTO_FAILED_RETRIEVINGPHOTO) + e.toString(), e);
			}

		}

	@Override
	public boolean getFinishButtonDisabled() {

		return false;
	}


	/**
	 * Generate Report
	 */
	@SuppressWarnings("unchecked")
	private void generateFromPOJO(){
		FacesContext fc = FacesContext.getCurrentInstance();		
		
		try {
			
			// - Parameters to send to the report
			Map parameters = new HashMap();
			/* Product Report */
			parameters.put(PRODUCT_REPORT_DESCRIPTION, this.productData.getDescription());
			parameters.put(PRODUCT_REPORT_IMAGE, this.productData.getPhotoInputStream());
			parameters.put(PRODUCT_REPORT_KOOSSERY_LOGO, new FileInputStream(JASPER_REPORT_KOOSSERY_LOGO_PATH.getFile()));
			parameters.put(PRODUCT_REPORT_NAME, this.productData.getName());
			parameters.put(PRODUCT_REPORT_PRIZE, this.productData.getPrize());
			parameters.put(PRODUCT_REPORT_REFERENCE, this.productData.getRef());
			parameters.put(PRODUCT_REPORT_STOCK, this.productData.getStock());

			File file = JASPER_REPORT_CONTEXT_PATH.getFile();
			
			// - Execution
			JasperPrint jasperPrint = JasperFillManager.fillReport(new FileInputStream(file), parameters,new JREmptyDataSource());
			
			// - Create report as PDF FIle		
			this.reportBytes = JasperExportManager.exportReportToPdf(jasperPrint);


		} catch (Throwable e) {
			Utils.addErrorMessage(Application.getMessage(fc, MSG_PRODUCT_REPORT_FAILED_GENERATE) + e.toString(), e);
		}
	}

	/**
	 * Create the report in PDF Format an register it in the repository
	 * @param bytes
	 */
	private void saveReport(byte[] bytes){
		UserTransaction tx = null;
		TransactionService transactionService = serviceRegistry.getTransactionService();
		FacesContext fc = FacesContext.getCurrentInstance();
		
		String mimeType;
		String objectType;
		String encoding;
		
		try {
			tx = transactionService.getUserTransaction();
			tx.begin();

			
			Map<QName, Serializable> nodeProperties = new HashMap<QName, Serializable>();

			String nodeName = this.productRef+".pdf";
			nodeProperties.put(ContentModel.PROP_NAME, nodeName);
			nodeProperties.put(ContentModel.PROP_DESCRIPTION, this.productData.getDescription());

			// Product Properties
			nodeProperties.put(ProductModel.PROP_NAME, this.productData.getName());
			nodeProperties.put(ProductModel.PROP_DESCRIPTION, this.productData.getDescription());
			this.productData.setRef(this.productRef);
			nodeProperties.put(ProductModel.PROP_REF, this.productRef);
			nodeProperties.put(ProductModel.PROP_PRIZE, this.productData.getPrize());
			nodeProperties.put(ProductModel.PROP_STOCK, this.productData.getStock());

			mimeType = Repository.getMimeTypeForFileName(fc, nodeName);
			encoding = "UTF-8";
			objectType = ProductModel.TYPE_PRODUCT.toString();
			
			this.productData.setFileInputStream(new ByteArrayInputStream(this.reportBytes));
			  
			InputStream is = null;							
			try{
				is = new BufferedInputStream(this.productData.getFileInputStream());
				encoding = Repository.guessEncoding(fc, is, mimeType);
			}catch (Throwable e){
				  logger.error("Failed to get encoding", e);
			}finally{
				try { is.close(); } catch (Throwable e) {} 
			}

			FileInfo fileInfo = this.getFileFolderService().create(
					CustomContentUtils.getCurrentContainerNodeRef(),
			        nodeName ,
		            Repository.resolveToQName(objectType));
			this.productData.setNodeRef(fileInfo.getNodeRef());
			
			// Fill in properties
			getNodeService().setProperties(this.productData.getNodeRef(), nodeProperties);
		    // set the auditable aspect
		    Map<QName, Serializable> auditableProps = new HashMap<QName, Serializable>();
		    Date now = new Date();
		    String author = getServiceRegistry().getAuthenticationService().getCurrentUserName();
		    auditableProps.put(ContentModel.PROP_CREATOR, author);
		    auditableProps.put(ContentModel.PROP_MODIFIER, author);
		    auditableProps.put(ContentModel.PROP_CREATED, now);
		    auditableProps.put(ContentModel.PROP_MODIFIED, now);

		    this.getNodeService().addAspect(this.productData.getNodeRef(), ContentModel.ASPECT_AUDITABLE, auditableProps);

		    // set the versionable aspect
		    Map<QName, Serializable> versionableProps = new HashMap<QName, Serializable>();

		    versionableProps.put(ContentModel.PROP_AUTO_VERSION, true);
		    versionableProps.put(ContentModel.PROP_INITIAL_VERSION, true);

		    this.getNodeService().addAspect(this.productData.getNodeRef(), ContentModel.ASPECT_VERSIONABLE, versionableProps);
		    
		    // set the author aspect
		    Map<QName, Serializable> authorProps = new HashMap<QName, Serializable>(1, 1.0f);
		    authorProps.put(ContentModel.PROP_AUTHOR, author);
		    this.getNodeService().addAspect(this.productData.getNodeRef(), ContentModel.ASPECT_AUTHOR, authorProps);


			// get a writer for the content and put the file
		    ContentWriter writer = getContentService().getWriter(this.productData.getNodeRef(), ContentModel.TYPE_CONTENT, true);
		    // set the mimetype and encoding
		    writer.setMimetype(mimeType);
		    writer.setEncoding(encoding);
		    
		    writer.putContent(this.productData.getFileInputStream());
		    		    
		    // Save Photos
		    savePhoto();
	    
			tx.commit();
			
			
		} catch (Throwable e) {
			Utils.addErrorMessage(Application.getMessage(fc, MSG_SAVEREPORT_FAILED_SAVINGREPORT) + e.toString(), e);
		}

	}

	/**
	 * Update report and save updated version in the repository
	 * @param bytes
	 */
	private void saveUpdateReport(byte[] bytes){

		UserTransaction tx = null;
		TransactionService transactionService = serviceRegistry.getTransactionService();
		FacesContext fc = FacesContext.getCurrentInstance();
		
		String mimeType;
		String encoding;
		
		try {
			tx = transactionService.getUserTransaction();
			tx.begin();

			String nodeName = (String)getNodeService().getProperty(this.productData.getNodeRef(), ContentModel.PROP_NAME);

			// Update Product Properties
			getNodeService().setProperty(this.productData.getNodeRef(), ContentModel.PROP_DESCRIPTION, this.productData.getDescription());
			getNodeService().setProperty(this.productData.getNodeRef(), ProductModel.PROP_NAME, this.productData.getName());
			getNodeService().setProperty(this.productData.getNodeRef(), ProductModel.PROP_DESCRIPTION, this.productData.getDescription());
			getNodeService().setProperty(this.productData.getNodeRef(), ProductModel.PROP_REF, this.productData.getRef());
			getNodeService().setProperty(this.productData.getNodeRef(), ProductModel.PROP_PRIZE, this.productData.getPrize());
			getNodeService().setProperty(this.productData.getNodeRef(), ProductModel.PROP_STOCK, this.productData.getStock());

			mimeType = Repository.getMimeTypeForFileName(fc, nodeName);
			encoding = "UTF-8";
			
			this.productData.setFileInputStream(new ByteArrayInputStream(this.reportBytes));
			  
			InputStream is = null;							
			try{
				is = new BufferedInputStream(this.productData.getFileInputStream());
				encoding = Repository.guessEncoding(fc, is, mimeType);
			}catch (Throwable e){
				  logger.error("Failed to get encoding", e);
			}finally{
				try { is.close(); } catch (Throwable e) {} 
			}
			
		    // set the auditable aspect
		    Map<QName, Serializable> auditableProps = new HashMap<QName, Serializable>();
		    Date now = new Date();
		    String currentUser = getServiceRegistry().getAuthenticationService().getCurrentUserName();
		    auditableProps.put(ContentModel.PROP_CREATOR, (String)getNodeService().getProperty(this.productData.getNodeRef(), ContentModel.PROP_CREATOR));
		    auditableProps.put(ContentModel.PROP_MODIFIER, currentUser);
		    auditableProps.put(ContentModel.PROP_CREATED, (Date)getNodeService().getProperty(this.productData.getNodeRef(), ContentModel.PROP_CREATED));
		    auditableProps.put(ContentModel.PROP_MODIFIED, now);

		    this.getNodeService().addAspect(this.productData.getNodeRef(), ContentModel.ASPECT_AUDITABLE, auditableProps);
		    
			// get a writer for the content and put the file
		    ContentWriter writer = getContentService().getWriter(this.productData.getNodeRef(), ContentModel.TYPE_CONTENT, true);
		    // set the mimetype and encoding
		    writer.setMimetype(mimeType);
		    writer.setEncoding(encoding);
		    
		    writer.putContent(this.productData.getFileInputStream());
		    
			tx.commit();
			
		} catch (Throwable e) {
			Utils.addErrorMessage(Application.getMessage(fc, MSG_SAVEUPDATEDREPORT_FAILED_SAVINGUPDATEDREPORT) + e.toString(), e);
		}


	}
	/**
	 * Save photo
	 */
	private void savePhoto(){
		
		FacesContext fc = FacesContext.getCurrentInstance();
		try {
			
			// Fill properties
			getNodeService().setProperty(this.productData.getPhotoNodeRef(), ProductModel.PROP_PICTURELEGEND,this.productData.getPhotoLegend());

			// set the auditable aspect
			Map<QName, Serializable> auditProperties = new HashMap<QName, Serializable>();
			Date now = new Date();
			String author = getServiceRegistry().getAuthenticationService().getCurrentUserName();
			auditProperties.put(ContentModel.PROP_CREATOR, author);
			auditProperties.put(ContentModel.PROP_MODIFIER, author );
			auditProperties.put(ContentModel.PROP_CREATED, now);
			auditProperties.put(ContentModel.PROP_MODIFIED, now);

		  	this.getNodeService().addAspect(this.productData.getPhotoNodeRef(), ContentModel.ASPECT_AUDITABLE, auditProperties);

		    // set the author aspect
		    Map<QName, Serializable> authorProps = new HashMap<QName, Serializable>(1, 1.0f);
		    authorProps.put(ContentModel.PROP_AUTHOR, author);
		    this.getNodeService().addAspect(this.productData.getPhotoNodeRef(), ContentModel.ASPECT_AUTHOR, authorProps);

			// Set association
			getNodeService().createAssociation(this.productData.getNodeRef(), this.productData.getPhotoNodeRef(), ProductModel.ASSOC_IMAGE);
		} catch (Throwable e) {

			Utils.addErrorMessage(Application.getMessage(fc, MSG_SAVEPHOTO_FAILED_SAVINGPHOTO) + e.toString(), e);
		} 
	}

	/**
	 * @param fileName The name of the picture file
	 */
	public void setPhotoFileName(String fileName)
	{
		FacesContext fc = FacesContext.getCurrentInstance();
		File photoFile = null;
		String mimeType;
		String objectType;
		String encoding;
		
		try {
			
			// we also need to keep the file upload bean in sync
			FileUploadBean fileBean = (FileUploadBean)fc.getExternalContext().getSessionMap().get(FileUploadBean.FILE_UPLOAD_BEAN_NAME);
			
			if (fileBean != null)
			  {	
					this.productData.setPhotoFileName(fileName);
				 	fileBean.setFileName(fileName);
				 	
				 	photoFile = fileBean.getFile();
				 	
					if(photoFile!=null){
				      try {
				    	
						mimeType = Repository.getMimeTypeForFileName(fc, fileName);
						encoding = "UTF-8";
						objectType = ProductModel.TYPE_IMAGE.toString();
						  
						InputStream is = null;							
						  try
						  {
							  is = new BufferedInputStream(new FileInputStream(photoFile));
							  encoding = Repository.guessEncoding(fc, is, mimeType);
						  }
						  catch (Throwable e)
						  {
						     // Not terminal
						     logger.error("Failed to get encoding from file: " + photoFile, e);
						  }
						  finally
						  {
						     try { is.close(); } catch (Throwable e) {} 
						  }
							  	
						  String nodeName = ""+System.currentTimeMillis()+"-"+fileName;
						  
							FileInfo fileInfo = this.getFileFolderService().create(
								  CustomContentUtils.getGuestHome(),
						          nodeName ,
						          Repository.resolveToQName(objectType));

						  NodeRef fileNodeRef = fileInfo.getNodeRef();
						  
						  getNodeService().setProperty(fileNodeRef, ContentModel.PROP_NAME, nodeName);
						  getNodeService().setProperty(fileNodeRef, ContentModel.PROP_DESCRIPTION, "A product");
					    
						  // set the auditable aspect
						  Map<QName, Serializable> nodeProperties = new HashMap<QName, Serializable>();
						  Date now = new Date();
						  String author = getServiceRegistry().getAuthenticationService().getCurrentUserName();
						  nodeProperties.put(ContentModel.PROP_CREATOR, author);
						  nodeProperties.put(ContentModel.PROP_MODIFIER, author );
						  nodeProperties.put(ContentModel.PROP_CREATED, now);
						  nodeProperties.put(ContentModel.PROP_MODIFIED, now);

						  this.getNodeService().addAspect(fileNodeRef, ContentModel.ASPECT_AUDITABLE, nodeProperties);
					    
						  // set the author aspect
						  Map<QName, Serializable> authorProps = new HashMap<QName, Serializable>(1, 1.0f);
						  authorProps.put(ContentModel.PROP_AUTHOR, author);
						  this.getNodeService().addAspect(fileNodeRef, ContentModel.ASPECT_AUTHOR, authorProps);

						  // get a writer for the content and put the file
						  ContentWriter writer = getContentService().getWriter(fileNodeRef, ContentModel.PROP_CONTENT, true);
						  // set the mimetype and encoding
						  writer.setMimetype(mimeType);
						  writer.setEncoding(encoding);
					    
						  writer.putContent(photoFile);
					    
						  // remember the created node now
						  productData.setPhotoNodeRef(fileNodeRef);
						  productData.setPhotoInputStream(new FileInputStream(photoFile));
					    
						  // remove the file upload bean from the session
						  FacesContext ctx = FacesContext.getCurrentInstance();
						  ctx.getExternalContext().getSessionMap().remove(FileUploadBean.FILE_UPLOAD_BEAN_NAME);

						} catch (Throwable e) {
							Utils.addErrorMessage(Application.getMessage(fc, MSG_CREATEPRODUCT_FAILED_WRITINGPHOTOCONTENT) + e.toString(), e);	
						}
					}
						
			  }
		} catch (Throwable e) {
			Utils.addErrorMessage(Application.getMessage(fc, MSG_CREATEPRODUCT_FAILED_UPLOADINGPHOTO) + e.toString(), e);
			e.printStackTrace();
		}
		
	}

	/**
	 * @return Returns the name of the picture file
	 */
	public String getPhotoFileName(){
		
		if(productData.getPhotoNodeRef() !=null)
			return productData.getPhotoFileName();
		else
			return null;
	}
	
	public NodeRef getPhotoFileNodeRef(){
		if(productData.getPhotoNodeRef()!=null)
			return productData.getPhotoNodeRef();
		else 
			return null;
	}

	/**
	 * Generate a browser URL for the equipment picture content
	 * @return
	 */
	public String getPhotoUrl(){
		
		String photoUrl = null;
		
		if(this.productData.getPhotoNodeRef()!=null){
			String name = (String)getNodeService().getProperty(this.productData.getPhotoNodeRef(), ContentModel.PROP_NAME);
			photoUrl = DownloadContentServlet.generateBrowserURL(this.productData.getPhotoNodeRef(), name);
		}	       	       
       return photoUrl;		
	}


	/* -------------- I18N errors messages ------------------ */
	private static final String MSG_CREATEPRODUCT_FAILED_WRITINGPHOTOCONTENT = "createProduct_err_failed_writingPhotoContent";
	private static final String MSG_CREATEPRODUCT_FAILED_UPLOADINGPHOTO = "createProduct_err_failed_uploadingProductPhoto";
	private static final String MSG_PRODUCT_REPORT_FAILED_GENERATE = "generateProductReport_err_failed_reportGeneration";
	private static final String MSG_RETRIEVEPHOTO_FAILED_RETRIEVINGPHOTO = "retrievePhoto_err_failed_retrievingPhoto";
	private static final String MSG_SAVEREPORT_FAILED_SAVINGREPORT = "saveReport_err_failed_savingPhoto";
	private static final String MSG_SAVEUPDATEDREPORT_FAILED_SAVINGUPDATEDREPORT = "saveUpdatedReport_err_failed_savingUpdatedReport";
	private static final String MSG_SAVEPHOTO_FAILED_SAVINGPHOTO = "savePhoto_err_failed_savingPhoto";
	
	/* -------------- Getters and Setters ------------------ */
	public ContentService getContentService() {
		return contentService;
	}

	public void setContentService(ContentService contentService) {
		this.contentService = contentService;
	}

	public ServiceRegistry getServiceRegistry() {
		return serviceRegistry;
	}

	public void setServiceRegistry(ServiceRegistry serviceRegistry) {
		this.serviceRegistry = serviceRegistry;
	}

	public String getName() {
		return this.productData.getName();
	}

	public void setName(String name) {
		this.productData.setName(name);
	}

	public String getDescription() {
		return this.productData.getDescription();
	}

	public void setDescription(String description) {
		this.productData.setDescription(description);
	}

	public String getRef() {
		return this.productRef;
	}

	public void setRef(String ref) {
		this.productData.setRef(this.productRef);
	}

	public float getPrize() {
		return this.productData.getPrize();
	}

	public void setPrize(float prize) {
		this.productData.setPrize(prize);
	}

	public int getStock() {
		return this.productData.getStock();
	}

	public void setStock(int stock) {
		this.productData.setStock(stock);
	}

	public String getPictureLegend() {
		return this.productData.getPhotoLegend();
	}

	public void setPictureLegend(String pictureLegend) {
		this.productData.setPhotoLegend(pictureLegend);
	}

}
